@@ -31,7 +31,18 @@ class EdgeCacheTest(TestCase):
             {0: {'osmid': 14039949, 'oneway': True, 'name': 'York Street', 'highway': 'unclassified', 'maxspeed': '30', 'length': 34.217}}
         )
 
-    @skip('todo')
+    def test_get_no_graph(self):
+        self.assertEqual(
+            get_edge_data(1, 2, graph=None),
+            None
+        )
+
     def test_caching(self):
-        # Make sure it just does get_edge_data once
-        pass
+        self.assertEqual(
+            get_edge_data(389281, 135109553, graph=self.test_journey.graph),
+            {0: {'osmid': 14039949, 'oneway': True, 'name': 'York Street', 'highway': 'unclassified', 'maxspeed': '30', 'length': 34.217}}
+        )
+        self.assertEqual(
+            get_edge_data(389281, 135109553, graph=None),
+            {0: {'osmid': 14039949, 'oneway': True, 'name': 'York Street', 'highway': 'unclassified', 'maxspeed': '30', 'length': 34.217}}
+        )
